==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/admin/messages/de/modules.php <==
<?php

return [
    '%moduleName% - Set as default module' => '%moduleName% - Als Standard festlegen',
    '<strong>Module</strong> details' => '<strong>Modul</strong>-Informationen',
    'Activated' => 'Aktiviert',
    'Always activated' => 'Immer aktiviert',
    'Are you sure? *ALL* module data will be lost!' => 'Bist du sicher? *ALLE* Modul Daten gehen verloren!',
    'Are you sure? *ALL* module related data and files will be lost!' => 'Bist du sicher? *ALLE* Modul-abhängigen Daten und Dateien gehen verloren!',
    'Close' => 'Schließen',
    'Configure' => 'Konfigurieren',
    'Could not find requested module!' => 'Kann gesuchtes Modul nicht finden!',
    'Deactivated' => 'Deaktivieren',
    'Enable module...' => 'Modul aktivieren ...',
    'Here you can choose whether or not a module should be automatically activated on a space or user profile. If the module should be activated, choose "always activated".' => 'Hier kannst du entscheiden ob ein Modul automatisch innerhalb eines Space oder in einem Benutzerprofil aktiviert sein soll oder nicht. Soll das Modul immer aktiviert sein, wähle "Immer aktiviert".',
    'License not found or expired. Please contact the module publisher.' => 'Lizenz nicht gefunden oder abgelaufen. Bitte Herausgeber des Moduls kontaktieren.',
    'Module path %path% is not writeable!' => 'Modul Verzeichnis %path% ist nicht beschreibbar!',
    'Save' => 'Speichern',
    'Spaces' => 'Spaces',
    'This module doesn\'t provide further information.' => 'Dieses Modul liefert keine weiteren Informationen.',
    'Activate' => '',
    'Deprecated' => '',
    'Featured' => '',
    'Installed' => '',
    'Module "{moduleName}" has been updated to version {newVersion} successfully.' => '',
    'New' => '',
    'No modules found.' => '',
    'Not Installed' => '',
    'Official' => '',
    'Partner' => '',
    'Professional Edition' => '',
    'Space default state' => '',
    'Try other keywords or remove filters.' => '',
    'Update successful' => '',
    'User default state' => '',
    'Users' => '',
];

==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/modules/admin/messages/de/modules.php <==
<?php

return [
    '%moduleName% - Set as default module' => '%moduleName% - Als Standard festlegen',
    'Activated' => 'Aktiviert',
    'Always activated' => 'Immer aktiviert',
    'Are you sure? *ALL* module data will be lost!' => 'Bist du sicher? *ALLE* Modul Daten gehen verloren!',
    'Are you sure? *ALL* module related data and files will be lost!' => 'Bist du sicher? *ALLE* Modul-abhängigen Daten und Dateien gehen verloren!',
    'Close' => 'Schließen',
    'Could not find requested module!' => 'Kann gesuchtes Modul nicht finden!',
    'Deactivated' => 'Deaktivieren',
    'Deactivation of this module has not been completed yet. Please retry in a few minutes.' => 'Die Deaktivierung dieses Moduls wurde noch nicht abgeschlossen. Bitte versuche es in ein paar Minuten erneut.',
    'Enable module...' => 'Modul aktivieren ...',
    'Here you can choose whether or not a module should be automatically activated on a space or user profile. If the module should be activated, choose "always activated".' => 'Hier kannst du entscheiden ob ein Modul automatisch innerhalb eines Space oder in einem Benutzerprofil aktiviert sein soll oder nicht. Soll das Modul immer aktiviert sein, wähle "Immer aktiviert".',
    'Module path %path% is not writeable!' => 'Modul Verzeichnis %path% ist nicht beschreibbar!',
    'Save' => 'Speichern',
    'Space default state' => 'Space Standard Einstellung',
    'Spaces' => 'Spaces',
    'User default state' => 'Profil Standard Einstellung',
    'Users' => 'Benutzer',
    'Module deactivation in progress. This process may take a moment.' => '',
];
